#include <algorithm>
#include <iostream>
#include <numeric>
#include <cassert>
#include <vector>
#include <chrono>
#include <random>
#include <queue>
#include <ctime>

typedef long long llong;
const int MAXN = 100000 + 10;
const int INF  = 1e9;

int n, m;
int l[MAXN];
int r[MAXN];
int part[MAXN];
char sol[MAXN];
double begTime;
std::vector <std::pair <int,int>> byColor[MAXN];
std::vector <int> g[MAXN];

bool dfs(int node)
{
    for (const int &u : g[node])
    {
        if (part[u] == part[node])
        {
            return false;
        }

        if (part[u] == 0)
        {
            part[u] = 3 ^ part[node];
            if (!dfs(u))
            {
                return false;
            }
        }
    }

    return true;
}

void solve()
{
    for (int i = 1 ; i <= n ; ++i)
    {
        std::vector <int> intervals;
        for (int j = 1 ; j <= m ; ++j)
        {
            if ((l[j] <= i && i <= r[j]) || (r[j] < l[j] && (i <= r[j] || l[j] <= i)))
            {
                intervals.push_back(j);
            }
        }

        if (intervals.size() <= 1)
        {
            std::cout << "impossible\n";
            return;
        }

        for (int j = 0 ; j + 1 < intervals.size() ; ++j)
        {
            byColor[i].push_back({intervals[j], intervals[j + 1]});
        }
    }

    std::mt19937 rng(std::chrono::steady_clock::now().time_since_epoch().count());
    while ((clock() - begTime) < 0.29 * CLOCKS_PER_SEC)
    {
        for (int i = 1 ; i <= m ; ++i)
        {
            g[i].clear();
        }

        for (int i = 1 ; i <= n ; ++i)
        {
            int idx = rng() % byColor[i].size();
            g[byColor[i][idx].first].push_back(byColor[i][idx].second);
            g[byColor[i][idx].second].push_back(byColor[i][idx].first);
        }

        bool isOK = true;
        std::fill(part + 1, part + 1 + m, 0);
        for (int i = 1 ; i <= m && isOK ; ++i)
        {
            if (part[i] == 0)
            {
                part[i] = 1;
                isOK &= dfs(i);
            }
        }

        if (isOK)
        {
            for (int i = 1 ; i <= m ; ++i)
            {
                sol[i] = '0' + part[i] - 1;
            }
        } else
        {
            continue;
        }

        sol[m + 1] = '\0';
        std::cout << sol + 1 << '\n';
        return;
    }

    std::cout << "impossible\n";
}

void input()
{
    std::cin >> n >> m;
    for (int i = 1 ; i <= m ; ++i)
    {
        std::cin >> l[i] >> r[i];
    }
}

void fastIOI()
{
    std::ios_base :: sync_with_stdio(0);
    std::cout.tie(nullptr);
    std::cin.tie(nullptr);
}

int main()
{
    begTime = clock();
    fastIOI();
    input();
    solve();

    return 0;
}