#include <algorithm>
#include <iostream>
#include <numeric>
#include <cassert>
#include <vector>
#include <chrono>
#include <random>
#include <queue>
#include <ctime>

typedef long long llong;
const int MAXN = 100000 + 10;
const int INF  = 1e9;

int n, m;
int l[MAXN];
int r[MAXN];
int dep[MAXN];
int par[MAXN];
int wasIn[MAXN];
bool removed[MAXN];
int count[MAXN];
int parIdx[MAXN];
bool vis[MAXN];
int part[MAXN];
char sol[MAXN];
double begTime;
std::vector <std::pair <int,int>> byColor[MAXN];
std::vector <std::pair <int,int>> g[MAXN];
std::vector <int> g2[MAXN];

std::vector <std::vector <int>> conditions;

void dfs(int node)
{
    vis[node] = true;
    for (const auto &[u, idx] : g[node])
    {
        if (!vis[u])
        {
            dep[u] = dep[node] + 1;
            par[u] = node;
            parIdx[u] = idx;
            dfs(u); 
        } else if (dep[node] > dep[u] && (dep[node] - dep[u]) % 2 == 0)
        {
            int curr = node;
            std::vector <int> currentEdges;
            currentEdges.push_back(idx);
            while (curr != u)
            {
                currentEdges.push_back(parIdx[curr]);
                curr = par[curr];
            }

            conditions.push_back(currentEdges);
        }
    }
}

bool bipartiteDFS(int node)
{
    for (const int &u : g2[node])
    {
        if (part[u] == part[node])
        {
            return false;
        }

        if (part[u] == 0)
        {
            part[u] = 3 ^ part[node];
            if (!bipartiteDFS(u))
            {
                return false;
            }
        }
    }

    return true;
}

void solve()
{
    for (int i = 1 ; i <= n ; ++i)
    {
        std::vector <int> intervals;
        for (int j = 1 ; j <= m ; ++j)
        {
            if ((l[j] <= i && i <= r[j]) || (r[j] < l[j] && (i <= r[j] || l[j] <= i)))
            {
                intervals.push_back(j);
            }
        }

        if (intervals.size() <= 1)
        {
            std::cout << "impossible\n";
            return;
        }

        for (int j = 0 ; j + 1 < intervals.size() ; ++j)
        {
            byColor[i].push_back({intervals[j], intervals[j + 1]});
        }
    }

    std::vector <std::pair <int,int>> edges;
    for (int i = 1 ; i <= n ; ++i)
    {
        for (const auto &[u, v] : byColor[i])
        {
            wasIn[edges.size()] = i;
            g[u].push_back({v, edges.size()});
            g[v].push_back({u, edges.size()});
            edges.push_back({u, v});
        }
    }

    for (int i = 1 ; i <= m ; ++i)
    {
        if (!vis[i])
        {
            dfs(i);
        }
    }


    // std::mt19937 rng(std::chrono::steady_clock::now().time_since_epoch().count());
    for (int i = 0 ; i < conditions.size() ; ++i)
    {
        for (int j = 0 ; j < conditions[i].size() ; ++j)
        {
            count[conditions[i][j]]++;
        }
    }

    int toRemove = conditions.size();
    while (toRemove > 0)
    {
        int maxCount = 0;
        for (int i = 0 ; i < edges.size() ; ++i)
        {
            if (removed[i])
            {
                continue;
            }

            if (removed[maxCount] || count[i] > count[maxCount])
            {
                maxCount = i;
            }
        }
        
        if (maxCount < 15)
        {
            break;
        }

        // std::cout << "remove: " << toRemove << ' ' << maxCount << ' ' << count[maxCount] << '\n';
        toRemove -= count[maxCount];
        removed[maxCount] = true;
        for (int i = 0 ; i < conditions.size() ; ++i)
        {
            for (int j = 0 ; j < conditions[i].size() ; ++j)
            {
                if (conditions[i][j] == maxCount)
                {
                    conditions[i].clear();
                }
            }
        }
    }

    for (int i = 1 ; i <= m ; ++i)
    {
        g[i].clear();
    }

    for (int i = 1 ; i <= n ; ++i)
    {
        byColor[i].clear();
    }

    int countRemained = 0;
    // std::cout << "edges size: " << edges.size() << '\n';
    for (int i = 0 ; i < edges.size() ; ++i)
    {
        if (removed[i])
        {
            // std::cout << "was removed: " << edges[i].first << ' ' << edges[i].second << '\n' << std::flush;
            continue;
        }

        // std::cout << "was readded: " << wasIn[i] << ' ' << edges[i].first << ' ' << edges[i].second << '\n';
        countRemained++;    
        byColor[wasIn[i]].push_back(edges[i]);
    }

    bool empty = false;
    for (int i = 1 ; i <= m ; ++i)
    {
        empty |= byColor[i].empty();
    }

    if (countRemained < n || empty) 
    {
        std::cout << "impossible\n";
        return;
    }

    // exit(0);
    std::mt19937 rng(std::chrono::steady_clock::now().time_since_epoch().count());
    while ((clock() - begTime) < 0.29 * CLOCKS_PER_SEC)
    {
        for (int i = 1 ; i <= m ; ++i)
        {
            g2[i].clear();
        }

        for (int i = 1 ; i <= n ; ++i)
        {
            int idx = rng() % byColor[i].size();
            g2[byColor[i][idx].first].push_back(byColor[i][idx].second);
            g2[byColor[i][idx].second].push_back(byColor[i][idx].first);
        }

        bool isOK = true;
        std::fill(part + 1, part + 1 + m, 0);
        for (int i = 1 ; i <= m && isOK ; ++i)
        {
            if (part[i] == 0)
            {
                part[i] = 1;
                isOK &= bipartiteDFS(i);
            }
        }

        if (isOK)
        {
            for (int i = 1 ; i <= m ; ++i)
            {
                sol[i] = '0' + part[i] - 1;
            }
        } else
        {
            continue;
        }

        sol[m + 1] = '\0';
        std::cout << sol + 1 << '\n';
        return;
    }

    std::cout << "impossible\n";
}

void input()
{
    std::cin >> n >> m;
    for (int i = 1 ; i <= m ; ++i)
    {
        std::cin >> l[i] >> r[i];
    }
}

void fastIOI()
{
    std::ios_base :: sync_with_stdio(0);
    std::cout.tie(nullptr);
    std::cin.tie(nullptr);
}

int main()
{
    begTime = clock();
    fastIOI();
    input();
    solve();

    return 0;
}