#include <algorithm>
#include <iostream>
#include <numeric>
#include <cassert>
#include <vector>
#include <stack>

#pragma GCC optimize ("O3")
#pragma GCC target ("sse4")

typedef long long llong;
const int MAXN = 100;
const int INF  = 1e9;

int n = 1;
int sum[MAXN];
int perm[MAXN];
std::string s;
std::vector <std::pair <int,int>> g[MAXN];

int ptr;
bool dfs(int node)
{
    if (g[node].empty())
    {
        sum[node] = perm[++ptr];
        return true;
    }

    int bal = 0;
    sum[node] = 0;
    for (const auto &[u, dist] : g[node])
    {
        if (!dfs(u))
        {
            return false;
        }

        bal += dist * sum[u];
        sum[node] += sum[u];
    }

    return (bal == 0);
}

std::string ans;
void sol(int node)
{
    if (g[node].empty())
    {
        std::string toAdd;
        int num = perm[++ptr];
        while (num > 0)
        {
            toAdd += '0' + num % 10;
            num /= 10;
        }

        std::reverse(toAdd.begin(), toAdd.end());
        ans += toAdd;
        return;
    }

    ans += '(';
    for (int i = 0 ; i < g[node].size() ; ++i)
    {
        sol(g[node][i].first);
        if (i + 1 < g[node].size())
        {
            ans += ',';
        }
    }

    ans += ')';
}

void solve()
{
    std::stack <int> nodes;

    int value = 0;
    bool isNegative = false;
    bool lastIsClosing = false;
    for (const char &c : s)
    {
        if (c == ' ')
        {
            continue;
        }

        if (c == '(')
        {
            if (n != 1)
            {
                g[nodes.top()].push_back({n, (isNegative ? -value : value)});
                value = 0;
                isNegative = false;
            }

            nodes.push(n);
            n++;
            lastIsClosing = false;
            continue;
        }

        if (c == ')')
        {
            if (!lastIsClosing)
            {
                // std::cout << "push: " << nodes.top() << ' ' << n << '\n';
                g[nodes.top()].push_back({n, (isNegative ? -value : value)});
                n++;
                value = 0;
                isNegative = false;            
                lastIsClosing = true;
            }

            nodes.pop();
            continue;
        }

        if (c == ',')
        {
            if (lastIsClosing)
            {
                lastIsClosing = false;
                continue;
            }

            // std::cout << "push: " << nodes.top() << ' ' << n << '\n';
            g[nodes.top()].push_back({n, (isNegative ? -value : value)});
            n++;
            value = 0;
            isNegative = false;
            lastIsClosing = false;
            continue;
        }

        if (c == '-')
        {
            isNegative = true;
            lastIsClosing = false;
            continue;
        }

        if (isdigit(c))
        {
            value = 10 * value + c - '0';
            lastIsClosing = false;
            continue;
        }

        assert(false);
    }

    n--;
    int cntLeaves = 0;
    for (int i = 1 ; i <= n ; ++i)
    {
        cntLeaves += (g[i].empty());
    }

    // std::cout << n << '\n';
    // for (int i = 1 ; i <= n ; ++i)
    // {
    //     for (const auto &[u, val] : g[i])
    //     {
    //         std::cout << i << ' ' << u << ' ' << val << '\n';
    //     }
    // }

    // exit(0);
    // std::cout << cntLeaves << '\n' << std::flush;
    std::iota(perm + 1, perm + 1 + cntLeaves, 1);
    do
    {
        ptr = 0;
        if (dfs(1))
        {
            break;
        }
    } while (std::next_permutation(perm + 1, perm + 1 + cntLeaves));

    ptr = 0;
    assert(dfs(1));
    ptr = 0;
    sol(1);

    std::cout << ans << '\n';
}   

void input()
{
    std::cin >> s;
}

void fastIOI()
{
    std::ios_base :: sync_with_stdio(0);
    std::cout.tie(nullptr);
    std::cin.tie(nullptr);
}

int main()
{
    fastIOI();
    input();
    solve();

    return 0;
}