#include <algorithm>
#include <iostream>
#include <numeric>
#include <cassert>
#include <vector>
#include <stack>

#pragma GCC optimize ("O3")
#pragma GCC target ("sse4")

typedef long long llong;
const int MAXN = 100;
const int INF  = 1e9;

int n = 1;
int cntLeaves;
int cntChoose;
int sum[MAXN];
int perm[MAXN];
bool shouldTake[MAXN];
std::vector <std::pair <int,int>> g[MAXN];
bool taken2[MAXN];
bool taken[MAXN];
std::string s;

int value(int bal, int dist)
{
    bal = -bal;
    if ((bal < 0) ^ (dist < 0)) return -1;
    bal = abs(bal); dist = abs(dist);
    if (bal % dist != 0) return -1;
    return bal / dist;
}

int ptr;
bool dfs(int node)
{
    if (g[node].empty())
    {
        sum[node] = perm[++ptr];
        return true;
    }

    int bal = 0;
    sum[node] = 0;
    for (const auto &[u, dist] : g[node])
    {
        if (shouldTake[u])
        {
            continue;
        }
        
        if (!dfs(u))
        {
            return false;
        }

        bal += dist * sum[u];
        sum[node] += sum[u];
    }

    for (const auto &[u, dist] : g[node])
    {
        if (shouldTake[u] && (value(bal, dist) == -1 || taken[value(bal, dist)]))
        {
            return false;
        }
        
        if (shouldTake[u])
        {
            sum[u] = value(bal, dist);
            taken[sum[u]] = true;
            bal += dist * sum[u];
            sum[node] += sum[u];
        }
    }

    return (bal == 0);
}   

std::string ans;
void sol(int node)
{
    if (g[node].empty())
    {
        std::string toAdd;
        int num = sum[node];
        while (num > 0)
        {
            toAdd += '0' + num % 10;
            num /= 10;
        }

        std::reverse(toAdd.begin(), toAdd.end());
        ans += toAdd;
        return;
    }

    ans += '(';
    for (int i = 0 ; i < g[node].size() ; ++i)
    {
        sol(g[node][i].first);
        if (i + 1 < g[node].size())
        {
            ans += ',';
        }
    }

    ans += ')';
}

int here;
bool brute(int pos)
{
    if (pos == cntChoose + 1)
    {
        here++;
        ptr = 0;
        for (int i = 1 ; i <= n ; ++i)
        {
            taken[i] = taken2[i];
        }

        return dfs(1);
    }

    for (int i = 1 ; i <= cntLeaves ; ++i)
    {
        if (!taken2[i])
        {
            perm[pos] = i;
            taken2[i] = true;
            if (brute(pos + 1))
            {
                return true;
            }

            taken2[i] = false;
        }
    }

    return false;
}

void solve()
{
    std::stack <int> nodes;

    int value = 0;
    bool isNegative = false;
    bool lastIsClosing = false;
    for (const char &c : s)
    {
        if (c == ' ')
        {
            continue;
        }

        if (c == '(')
        {
            if (n != 1)
            {
                g[nodes.top()].push_back({n, (isNegative ? -value : value)});
                value = 0;
                isNegative = false;
            }

            nodes.push(n);
            n++;
            lastIsClosing = false;
            continue;
        }

        if (c == ')')
        {
            if (!lastIsClosing)
            {
                // std::cout << "push: " << nodes.top() << ' ' << n << '\n';
                g[nodes.top()].push_back({n, (isNegative ? -value : value)});
                n++;
                value = 0;
                isNegative = false;            
                lastIsClosing = true;
            }

            nodes.pop();
            continue;
        }

        if (c == ',')
        {
            if (lastIsClosing)
            {
                lastIsClosing = false;
                continue;
            }

            // std::cout << "push: " << nodes.top() << ' ' << n << '\n';
            g[nodes.top()].push_back({n, (isNegative ? -value : value)});
            n++;
            value = 0;
            isNegative = false;
            lastIsClosing = false;
            continue;
        }

        if (c == '-')
        {
            isNegative = true;
            lastIsClosing = false;
            continue;
        }

        if (isdigit(c))
        {
            value = 10 * value + c - '0';
            lastIsClosing = false;
            continue;
        }

        assert(false);
    }

    n--;
    for (int i = 1 ; i <= n ; ++i)
    {
        cntLeaves += (g[i].empty());
    }

    cntChoose = cntLeaves;
    for (int i = 1 ; i <= n ; ++i)
    {
        for (auto &x : g[i])
        {
            if (g[x.first].empty())
            {
                // std::cout << "should take: " << x.first << '\n' << std::flush;
                shouldTake[x.first] = true;
                cntChoose--;
                break;
            }
        }
    }

    // std::cout << "leaves: " << cntLeaves << ' ' << cntChoose << '\n' << std::flush;
    assert(brute(1));
    ptr = 0;
    sol(1);

    std::cout << ans << '\n';
}   

void input()
{
    std::cin >> s;
}

void fastIOI()
{
    std::ios_base :: sync_with_stdio(0);
    std::cout.tie(nullptr);
    std::cin.tie(nullptr);
}

int main()
{
    fastIOI();
    input();
    solve();

    return 0;
}

/*
(-8,-4(-5,-3,-1,1),-2(-1,1,3),2(-1(-3,-2,1(-2,1,3)),1,3),6)
*/