#include <algorithm>
#include <iostream>
#include <numeric>
#include <cassert>
#include <vector>
#include <random>
#include <queue>
#include <stack>
#include <set>

typedef long long llong;
const int MAXN = 1e6 + 10;
const int INF  = 1e9;

int n, x;
struct Fenwick
{
    llong tree[MAXN];
    void update(int idx, int value)
    {
        for (; idx <= n ; idx += idx & (-idx))
        {
            tree[idx] += value;
        }
    }

    llong query(int idx)
    {
        llong res = 0;
        for (; idx ; idx -= idx & (-idx))
        {
            res += tree[idx];
        }

        return res;
    }

    llong query(int l, int r)
    {
        return query(r) - query(l - 1);
    }
};

int a[MAXN];
int jump[MAXN];
llong dp[MAXN];
llong prefix[MAXN];
std::vector <int> add[MAXN];
Fenwick plus, multiplied;

int perm[MAXN];
void solve()
{
    for (int i = 1 ; i <= n ; ++i)
    {
        jump[i] = 0;
    }

    for (int i = 1 ; i <= n ; ++i)
    {
        jump[std::max(1, i - a[i])] = std::max(jump[std::max(1, i - a[i])], std::min(n, i + a[i]) + 1);
    }

    for (int i = 2 ; i <= n ; ++i)
    {
        jump[i] = std::max(jump[i], jump[i - 1]);
    }

    // std::cout << "jump\n";
    // for (int i = 1 ; i <= n ; ++i)
    // {
    //     std::cout << jump[i] << ' ';
    // }

    // std::cout << '\n';
    llong answer = 0;
    for (int i = n ; i >= 1 ; --i)
    {
        dp[i] = dp[jump[i]] + n + 1 - jump[i];
        answer += dp[i];
    }

    for (int i = 1 ; i <= n ; ++i)
    {
        prefix[i] = prefix[i - 1] + dp[i];
    }

    llong ans = answer;
    for (int i = 1 ; i <= n ; ++i)
    {
        if (a[i] >= x)
        {
            continue;
        }

        int currJump = std::min(n, i + x) + 1;
        int l = 0, r = n + 1, mid;
        while (l < r - 1)
        {
            mid = l + r >> 1;
            if (jump[mid] < currJump) l = mid;
            else r = mid;
        }

        int idx = std::max(1, i - x);
        if (l < idx)
        {
            continue;
        }

        llong current = answer;
        current -= prefix[l] - prefix[idx - 1];
        current += 1LL * (l - idx + 1) * (dp[currJump] + n + 1 - currJump);
        current += plus.query(idx, l) * (dp[currJump] + n + 1 - currJump);
        current += multiplied.query(l + 1, n);
        // std::cout << "current: " << i << " = " << current << '\n';
        ans = std::min(ans, current);
        if (i > x)
        {
            answer += (plus.query(i - x, i - x) + 1) * (n + 1 - jump[i - x]);
            plus.update(jump[i - x], plus.query(i - x, i - x) + 1);
            multiplied.update(jump[i - x], (plus.query(i - x, i - x) + 1) * dp[jump[i - x]]);
        }
    }

    std::cout << ans << '\n';
}   

void input()
{
    std::cin >> n >> x;
    for (int i = 1 ; i <= n ; ++i)
    {
        std::cin >> a[i];
    }
}

void fastIOI()
{
    std::ios_base :: sync_with_stdio(0);
    std::cout.tie(nullptr);
    std::cin.tie(nullptr);
}

int main()
{
    fastIOI();
    input();
    solve();

    return 0;
}